@@ -48,6 +48,20 @@ def ExecuteStoredProc(storedProcName, parametrs):
         c.close()
 
 
+def ExecuteStoredProcRows(storedProcName, parametrs):
+    c = connection.cursor()
+    try:
+        # c.execute("BEGIN")
+        res = c.callproc(storedProcName, parametrs)
+        results = c.fetchall()
+        # c.execute("COMMIT")
+        return results
+    except Exception as ex:
+        logger.error(ex)
+        raise ex
+    finally:
+        c.close()
+
 class Common:
     @staticmethod
     def get_size_file_str(value):
