@@ -836,7 +836,7 @@ class CommonManager(Manager):
                 else:
                     logger.warning(f'Element {_data} not found')
 
-        _res = {}
+        _res = dict()
         if isinstance(res, dict):
             for key, value in res.items():
                 if not isinstance(value, list) and not isinstance(value, dict):
