@@ -22,7 +22,7 @@ class ProgressDroped(Exception):
 
 
 @contextmanager
-def managed_progress(qty, user, id, message='Обработано позиций', title='Обработано позиций', props=0):
+def managed_progress(qty, user, id, message='Обработано позиций', title='Обработано позиций', props=0, sendError=True):
     progress = Progress(id=id, qty=qty, user=user, message=message, title=title, props=props)
     try:
         yield progress
@@ -40,8 +40,13 @@ def managed_progress(qty, user, id, message='Обработано позиций
         stackTrace = traceback.format_exception(*exc_info)
         stackTrace = '<br>'.join(stackTrace)
         stackTrace = f'<pre>{stackTrace}</pre>'
+
+        if sendError is True:
+            progress.sendError(message=str(ex), stackTrace=stackTrace)
+        else:
+            logger.exception(msg=str(ex), exc_info=exc_info)
+
         del exc_info
-        progress.sendError(message=str(ex), stackTrace=stackTrace)
 
         progress.close()
         raise ex
